==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/StreamInputStream.h <==
// class gnu.java.net.protocol.ftp.StreamInputStream

// class file dependencies
// @dep_class d85c82adc9496692 gnu_java_net_protocol_ftp_DTPInputStream
// @dep_class b4985ca18b66aab2 gnu_java_net_protocol_ftp_StreamInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_net_protocol_ftp_DTPInputStream

#include "gnu/java/net/protocol/ftp/DTPInputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_StreamInputStream_H_
#define _JC_gnu_java_net_protocol_ftp_StreamInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$refs	_jc_gnu_java_net_protocol_ftp_StreamInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_StreamInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object	_jc_gnu_java_net_protocol_ftp_StreamInputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vmethods	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vtable	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vtype	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_StreamInputStream$method$_init$6ecf86878bba3fe8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *, struct _jc_object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern jint _jc_gnu_java_net_protocol_ftp_StreamInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *);
extern jint _jc_gnu_java_net_protocol_ftp_StreamInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *, struct _jc_byte_array *);
extern jint _jc_gnu_java_net_protocol_ftp_StreamInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *);
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *, struct _jc_byte_array *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods	gnu_java_net_protocol_ftp_DTPInputStream;
	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vmethods	gnu_java_net_protocol_ftp_StreamInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$refs {
    _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_refs	gnu_java_net_protocol_ftp_StreamInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_StreamInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object {
	_jc_gnu_java_net_protocol_ftp_StreamInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_StreamInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_StreamInputStream$vtype _jc_gnu_java_net_protocol_ftp_StreamInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_StreamInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_StreamInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_StreamInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/StreamInputStream.h <==
// class gnu.java.net.protocol.ftp.StreamInputStream

// class file dependencies
// @dep_class d85c82adc9496692 gnu_java_net_protocol_ftp_DTPInputStream
// @dep_class b4985ca18b66aab2 gnu_java_net_protocol_ftp_StreamInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_net_protocol_ftp_DTPInputStream

#include "gnu/java/net/protocol/ftp/DTPInputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_StreamInputStream_H_
#define _JC_gnu_java_net_protocol_ftp_StreamInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$refs	_jc_gnu_java_net_protocol_ftp_StreamInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_StreamInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object	_jc_gnu_java_net_protocol_ftp_StreamInputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vmethods	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vtable	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vtype	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_StreamInputStream$method$_init$6ecf86878bba3fe8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *, struct _jc_object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_protocol_ftp_StreamInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_ftp_StreamInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_ftp_StreamInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_java_net_protocol_ftp_StreamInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods	gnu_java_net_protocol_ftp_DTPInputStream;
	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vmethods	gnu_java_net_protocol_ftp_StreamInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$refs {
    _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_refs	gnu_java_net_protocol_ftp_StreamInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_gnu_java_net_protocol_ftp_StreamInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_StreamInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_StreamInputStream$object {
	_jc_gnu_java_net_protocol_ftp_StreamInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_StreamInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_StreamInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_StreamInputStream$vtype _jc_gnu_java_net_protocol_ftp_StreamInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_StreamInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_StreamInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_StreamInputStream_H_ */
